summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorRandall Spangler <rspangler@chromium.org>2012-05-08 16:56:59 -0700
committerRandall Spangler <rspangler@chromium.org>2012-05-09 16:09:10 -0700
commit1655c8727a82d8a344400f1708d315decb57c73c (patch)
tree8df68e9691978bdc0a320b24b36ef6dcd30302ae /include
parent33422ee34169123a53bf47366e3ce474a6acfb3a (diff)
downloadchrome-ec-1655c8727a82d8a344400f1708d315decb57c73c.tar.gz
Add hooks for chipset power transitions
This is cleaner than having x86_power explicitly know about everything else in the system that cares about power transitions. Signed-off-by: Randall Spangler <rspangler@chromium.org> BUG=none TEST=boot and shutdown system; still works. Mouse powered to system is off in S5. Change-Id: Ib673ca2d9edd5473334e7604e98b99b02b768419
Diffstat (limited to 'include')
-rw-r--r--include/hooks.h26
-rw-r--r--include/usb_charge.h4
2 files changed, 18 insertions, 12 deletions
diff --git a/include/usb_charge.h b/include/usb_charge.h
index 714deb5235..b73f57a684 100644
--- a/include/usb_charge.h
+++ b/include/usb_charge.h
@@ -27,10 +27,6 @@ enum usb_charge_mode {
USB_CHARGE_MODE_COUNT
};
-int usb_charge_all_ports_on(void);
-
-int usb_charge_all_ports_off(void);
-
int usb_charge_set_mode(int usb_port_id, enum usb_charge_mode);
#endif /* __CROS_EC_USB_CHARGE_H */
diff --git a/include/hooks.h b/include/hooks.h
index a0e12e708b..8bce2166f7 100644
--- a/include/hooks.h
+++ b/include/hooks.h
@@ -18,14 +18,24 @@ enum hook_priority {
enum hook_type {
- HOOK_INIT = 0, /* System init */
- HOOK_FREQ_CHANGE, /* System clock changed frequency */
- HOOK_SYSJUMP, /* About to jump to another image. Modules which
- * need to preserve data across such a jump should
- * save it here and restore it in HOOK_INIT.
- *
- * NOTE: This hook is called with interrupts
- * disabled! */
+ HOOK_INIT = 0, /* System init */
+ HOOK_FREQ_CHANGE, /* System clock changed frequency */
+ HOOK_SYSJUMP, /* About to jump to another image. Modules
+ * which need to preserve data across such a
+ * jump should save it here and restore it in
+ * HOOK_INIT.
+ *
+ * NOTE: This hook is called with interrupts
+ * disabled! */
+ HOOK_CHIPSET_STARTUP, /* System is starting up. All suspend rails are
+ * now on. */
+ HOOK_CHIPSET_RESUME, /* System is resuming from suspend, or booting
+ * and has reached the point where all voltage
+ * rails are on */
+ HOOK_CHIPSET_SUSPEND, /* System is suspending, or shutting down; all
+ * voltage rails are still on */
+ HOOK_CHIPSET_SHUTDOWN, /* System is shutting down. All suspend rails
+ * are still on. */
};